import { fileIsExist } from '@kevisual/use-config';
import { useFileStore } from '@kevisual/use-config/file-store';
import fs from 'fs';
import path from 'path';

export const baseUrl = 'https://cn.nikkei.com';

export const taskName = 'nikkei';
export const tabs = [
  {
    name: '日经精选',
    href: '/',
    children: [
      {
        href: '/top/nian-du-pan-dian-zhan-wang.html',
        text: '年度盘点展望',
      },
      {
        href: '/top/2021-04-20-01-47-39.html',
        text: '日本企业研究',
      },
      {
        href: '/top/2020-08-25-06-34-55.html?types[0]=8',
        text: '半导体/AI',
      },
      {
        href: '/top/2019-08-29-06-18-57.html',
        text: '中日深度观察',
      },
      {
        href: '/top/201604-3.html',
        text: '日本游',
      },
      {
        href: '/top/2021-03-03-07-02-53.html?types[0]=8',
        text: '脱碳经济',
      },
      {
        href: '/top/bp.html?types[0]=8',
        text: '日经BP精选',
      },
      {
        href: '/top/ft.html?types[0]=8',
        text: 'FT中文网精选',
      },
      {
        href: '/top/foa2024.html?types[0]=8',
        text: '亚洲的未来',
      },
    ],
  },
  {
    name: '中国',
    href: '/china.html',
    children: [
      {
        href: '/china/ceconomy.html',
        text: '经济',
      },
      {
        href: '/china/ccompany.html',
        text: '企业',
      },
      {
        href: '/china/cfinancial.html',
        text: '金融市场',
      },
      {
        href: '/china/cpolicssociety.html',
        text: '政治/社会',
      },
    ],
  },
  {
    name: '政经观察',
    href: '/politicsaeconomy.html',
    children: [
      {
        href: '/politicsaeconomy/epolitics.html',
        text: '宏观经济',
      },
      {
        href: '/politicsaeconomy/economic-policy.html',
        text: '经济政策',
      },
      {
        href: '/politicsaeconomy/stockforex.html',
        text: '股市/外汇',
      },
      {
        href: '/politicsaeconomy/investtrade.html',
        text: '投资/贸易',
      },
      {
        href: '/politicsaeconomy/efinance.html',
        text: '金融',
      },
      {
        href: '/politicsaeconomy/commodity.html',
        text: '大宗商品',
      },
      {
        href: '/politicsaeconomy/politicsasociety.html',
        text: '政治/社会',
      },
    ],
  },
  {
    name: '产业聚焦',
    href: '/industry.html',
    children: [
      {
        href: '/industry/icar.html',
        text: '汽车',
      },
      {
        href: '/industry/itelectric-appliance.html',
        text: 'IT/家电',
      },
      {
        href: '/industry/ienvironment.html',
        text: '环境/能源',
      },
      {
        href: '/industry/manufacturing.html',
        text: '工业',
      },
      {
        href: '/industry/agriculture.html',
        text: '农林水产',
      },
      {
        href: '/industry/propertiesconstruction.html',
        text: '地产/建设',
      },
      {
        href: '/industry/tradingretail.html',
        text: '商业/消费',
      },
      {
        href: '/industry/scienceatechnology.html',
        text: '科学/技术',
      },
      {
        href: '/industry/management-strategy.html',
        text: '经营/战略',
      },
    ],
  },
  {
    name: '新产品',
    href: '/product.html',
    children: [
      {
        href: '/product/pdigital.html',
        text: '数码与家电',
      },
      {
        href: '/product/automobile.html',
        text: '汽车',
      },
      {
        href: '/product/beautyahealth.html',
        text: '美容与健康',
      },
      {
        href: '/product/prime-goods.html',
        text: '美品精选',
      },
      {
        href: '/product/joke-goods.html',
        text: '非凡创意',
      },
    ],
  },
  {
    name: '穿梭日本',
    href: '/trend.html',
    children: [
      {
        href: '/trend/cool-japan.html',
        text: '酷日本',
      },
      {
        href: '/trend/beautyahealth.html',
        text: '美容健身',
      },
      {
        href: '/trend/traditional-culture.html',
        text: '文化精粹',
      },
      {
        href: '/trend/tourism.html',
        text: '日本逍遥行',
      },
    ],
  },
  {
    name: '专栏/观点',
    href: '/columnviewpoint.html',
    children: [
      {
        href: '/columnviewpoint/tearoom.html',
        text: '中日茶坊',
      },
      {
        href: '/columnviewpoint/columns-b.html',
        text: '肖敏捷论中日',
      },
      {
        href: '/columnviewpoint/column-special1.html',
        text: '日本人小声说',
      },
      {
        href: '/columnviewpoint/liudicolumn.html',
        text: '刘迪观察',
      },
      {
        href: '/columnviewpoint/zhangshicolumn.html',
        text: '张石的樱雪鸿泥',
      },
      {
        href: '/columnviewpoint/kelongcolumn.html',
        text: '老柯要说话',
      },
      {
        href: '/columnviewpoint/criticism.html',
        text: '社评',
      },
      {
        href: '/columnviewpoint/viewpoint.html',
        text: '观点',
      },
      {
        href: '/columnviewpoint/column.html',
        text: '专栏',
      },
    ],
  },
  {
    name: '职场/深造',
    href: '/career.html',
    children: [
      {
        href: '/career/humanresource.html',
        text: '人才活用',
      },
      {
        href: '/career/employment.html',
        text: '就业',
      },
      {
        href: '/career/abroadstudy.html',
        text: '留学/教育',
      },
    ],
  },
];

export const allTab = tabs.flatMap((tab) => {
  return tab.children.map((child) => {
    return {
      parentName: tab.name,
      parentHref: tab.href,
      ...child,
    };
  });
});

export const exampleTab = {
  parentName: '日经精选',
  parentHref: '/',
  href: '/top/bp.html?types[0]=8',
  text: '日经BP精选',
};

export const crawlConfigPathRawDir = `./config/${taskName}`;
export const crawlDataPathDir = `./data/${taskName}`;
export const crawlConfigPathRaw = path.join(crawlConfigPathRawDir, 'crawl-config.json');
export const crawlDataPath = useFileStore(crawlDataPathDir, {
  needExists: true,
});

export const crawlConfigPath = useFileStore(crawlConfigPathRawDir, {
  needExists: true,
});

export const getCrawlConfig = () => {
  try {
    const config = fs.readFileSync(crawlConfigPathRaw, 'utf-8');

    return JSON.parse(config);
  } catch (error) {
    setCrawlConfig({
      currentTabIndex: 0,
    });
    return {
      currentTabIndex: 0,
    };
  }
};

export const setCrawlConfig = (config: any) => {
  if (!fileIsExist(crawlConfigPathRawDir)) {
    fs.mkdirSync(crawlConfigPathRawDir, { recursive: true });
  }
  fs.writeFileSync(crawlConfigPathRaw, JSON.stringify(config, null, 2));
};
